@@ -7,7 +7,7 @@ use warnings;
 use Exporter::Lite;
 our @EXPORT_OK = qw(parse_netstat);
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our %SPEC;
 
@@ -57,7 +57,7 @@ sub parse_netstat {
                        (?<local_host>\S+?):(?<local_port>\w+)\s+
                        (?<foreign_host>\S+?):(?<foreign_port>\w+|\*)\s+
                        (?<state>\S+) (?: \s+ (?:
-                               (?<pid>\d+)/(?<program>\S+) |
+                               (?<pid>\d+)/(?<program>.+?) |
                                -
                        ))? \s*$!x
                            or return [400, "Invalid tcp line (#$i): $line"];
@@ -68,7 +68,7 @@ sub parse_netstat {
                        (?<local_host>\S+?):(?<local_port>\w+)\s+
                        (?<foreign_host>\S+?):(?<foreign_port>\w+|\*)\s+
                        (?: \s+ (?:
-                               (?<pid>\d+)/(?<program>\S+) |
+                               (?<pid>\d+)/(?<program>.+?) |
                                -
                        ))? \s*$!x
                            or return [400, "Invalid udp line (#$i): $line"];
@@ -79,7 +79,7 @@ sub parse_netstat {
             $line =~ m!^(?<proto>unix) \s+ (?<refcnt>\d+) \s+
                        \[\s*(?<flags>\S*)\s*\] \s+ (?<type>\S+) \s+
                        (?<state>\S+|\s+) \s+ (?<inode>\d+) \s+
-                       (?: (?: (?<pid>\d+)/(?<program>\S+) | - ) \s+)?
+                       (?: (?: (?<pid>\d+)/(?<program>.+?) | - ) \s+)?
                        (?<path>.*?)\s*$!x
                            or return [400, "Invalid unix line (#$i): $line"];
             %k = %+;
@@ -104,7 +104,7 @@ Parse::Netstat - Parse the output of Unix "netstat" command
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
